@@ -396,9 +396,13 @@ def _upload_or_copy_file(ctx, size, src_path, dest_bucket, dest_path):
             params = dict(Bucket=dest_bucket, Key=dest_path)
             s3_client = ctx.s3_client_provider.find_correct_client(S3Api.HEAD_OBJECT, dest_bucket, params)
             resp = s3_client.head_object(**params)
-        except S3NoValidClientError:
+        except ClientError:
             # Destination doesn't exist, so fall through to the normal upload.
             pass
+        except S3NoValidClientError:
+            # S3ClientProvider can't currently distinguish between a user that has PUT but not LIST permissions and a
+            # user that has no permissions. If we can't find a valid client, proceed to the upload stage anyway.
+            pass
         else:
             # Check the ETag.
             dest_size = resp['ContentLength']
